pub enum Assignment {
Database,
Cache,
Persistent,
Log,
}Expand description
Device assignment.
The applications use this enumeration to describe the intended purpose of the device.
Variants
Database
Metadata and database objects, indexes, and other database structures.
Cache
Disk manager cache (page pool).
Persistent
A persistent storage device that contains the data.
Log
A persistent storage device that contains the database log.