DataSource

Struct DataSource 

pub struct DataSource<'a> { /* private fields */ }
A data source.

A data source contains records (table rows) produced by a query.

Implementations

Source

impl<'a> DataSource<'a>

pub fn n_columns(&self) -> Result<usize>

Returns the number of columns in this data source.

pub fn column_info(&self, col: usize) -> Result<(Type, String)>

Returns the type and the name of the column at index col.

pub fn cursor(&self) -> Result<Cursor<'_>>

Creates a cursor for this data source.