pub struct Info { /* private fields */ }Expand description
Runtime information.
This structure can be used by the applications to get the configuration of the runtime: eXtremeDB version, data types and features supported, policies, capabilities, etc.
The methods of this structure correspond to the fields of the
mco_runtime_info_t structure declared in mco.h.
Refer to the eXtremeDB documentation for information on individual
parameters.
Examples
let runtime = Runtime::start(vec![]);
let caps = runtime.info();
println!(
"eXtremeDB version {}.{}.{}",
caps.mco_version_major(),
caps.mco_version_minor(),
caps.mco_build_number()
);Implementations
Sourceimpl Info
impl Info
pub fn mco_version_major(&self) -> u8
pub fn mco_version_minor(&self) -> u8
pub fn mco_build_number(&self) -> u16
pub fn mco_size_t(&self) -> usize
pub fn mco_offs_t(&self) -> usize
pub fn uint4_supported(&self) -> bool
pub fn float_supported(&self) -> bool
pub fn mco_checklevel(&self) -> u8
pub fn evaluation_version(&self) -> bool
pub fn large_database_supported(&self) -> bool
pub fn collation_supported(&self) -> bool
pub fn heap31_supported(&self) -> bool
pub fn bin_serialization_supported(&self) -> bool
pub fn fixedrec_supported(&self) -> bool
pub fn statistics_supported(&self) -> bool
pub fn events_supported(&self) -> bool
pub fn save_load_supported(&self) -> bool
pub fn object_initialization_supported(&self) -> bool
pub fn direct_index_field_access_supported(&self) -> bool
pub fn multiprocess_access_supported(&self) -> bool
pub fn object_repack_supported(&self) -> bool
pub fn transaction_logging_supported(&self) -> bool
pub fn cluster_supported(&self) -> bool
pub fn high_availability_supported(&self) -> bool
pub fn iot_supported(&self) -> bool
pub fn ha_multicast_supported(&self) -> bool
pub fn ha_incremental_replication_supported(&self) -> bool
pub fn binary_schema_evolution_supported(&self) -> bool
pub fn unicode_supported(&self) -> bool
pub fn wchar_supported(&self) -> bool
pub fn recovery_supported(&self) -> bool
pub fn disk_supported(&self) -> bool
pub fn direct_pointers_supported(&self) -> bool
pub fn persistent_object_supported(&self) -> bool
pub fn xml_import_export_supported(&self) -> bool
pub fn user_defined_index_supported(&self) -> bool
pub fn multifile_supported(&self) -> bool
pub fn multifile_descriptor_supported(&self) -> bool
pub fn two_phase_commit_supported(&self) -> bool
pub fn rtree_supported(&self) -> bool
pub fn tree_based_hash(&self) -> bool
pub fn tmgr_mvcc_async_cleanup(&self) -> bool
pub fn concurent_disk_btree(&self) -> bool
pub fn open_cursor_goto_first(&self) -> bool
pub fn smart_index_insert(&self) -> bool
pub fn btree_leaf_lock(&self) -> bool
pub fn null_statistics(&self) -> bool
pub fn implicit_runtime_start(&self) -> bool
pub fn bufferized_sync_iostream(&self) -> bool
pub fn async_replication(&self) -> bool
pub fn fast_transaction_list(&self) -> bool
pub fn extendable_dirty_page_bitmap(&self) -> bool
pub fn mursiw_policy(&self) -> u8
pub fn sync_capabilities(&self) -> u8
pub fn char_comparison_policy(&self) -> u8
pub fn stream_buffer_size(&self) -> usize
pub fn max_db_instances(&self) -> usize
pub fn max_db_name_length(&self) -> usize
pub fn max_extends(&self) -> isize
pub fn tl_page_buffer_size(&self) -> usize
pub fn ha_max_replicas(&self) -> usize
pub fn ha_transmit_buffer_size(&self) -> usize
pub fn ha_syncronization_buffer_size(&self) -> usize
pub fn default_redo_log_limit(&self) -> usize
pub fn mvcc_critical_sections(&self) -> usize
pub fn mvcc_per_index_locks(&self) -> usize
pub fn con_disk_page_cache_size(&self) -> usize
pub fn small_con_cache_threshold(&self) -> usize
pub fn extendable_dirty_page_bitmap_limit(&self) -> usize
pub fn max_vista_sessions(&self) -> usize
pub fn concurrent_write_transactions(&self) -> bool
pub fn encryption_support(&self) -> bool
pub fn backup_support(&self) -> bool
pub fn mco_revision(&self) -> &'static str